:orphan:

Bar charts auto-labeling
------------------------
A new `.Axes.bar_label` method has been added for auto-labeling bar charts.
See :doc:`/gallery/lines_bars_and_markers/bar_label_demo` for examples.

